Introspection — Introspection documentation

# Introspection

This module is a collection of new or improved introspection functions. Some functions are improved versions of the functions found in the `inspect` module, others are completely new.

The available functions have been roughly categorized by what they return or what kind of objects they operate on.

Contents:

- Function Signatures
- The call stack
- Functions related to classes
- Functions related to dundermethods
- Introspecting the `typing` module
- Misc. functions